==> discover-5.15.90.tar.xz: discover-5.15.90/libdiscover/appstream/AppStreamIntegration.cpp <==
/***************************************************************************
 *   Copyright © 2017 Aleix Pol Gonzalez <aleixpol@kde.org>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "AppStreamIntegration.h"
#include <KOSRelease>

AppStreamIntegration * AppStreamIntegration::global()
{
    static AppStreamIntegration * var = nullptr;
    if (!var) {
        var = new AppStreamIntegration;
    }

    return var;
}

QSharedPointer<OdrsReviewsBackend> AppStreamIntegration::reviews()
{
    QSharedPointer<OdrsReviewsBackend> ret;
    if (m_reviews) {
        ret = m_reviews;
    } else {
        ret = QSharedPointer<OdrsReviewsBackend>(new OdrsReviewsBackend(nullptr));
        m_reviews = ret;
    }
    return ret;
}

==> discover-5.19.5.tar.xz: discover-5.19.5/libdiscover/appstream/AppStreamIntegration.cpp <==
/***************************************************************************
 *   Copyright © 2017 Aleix Pol Gonzalez <aleixpol@kde.org>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "AppStreamIntegration.h"
#include <KOSRelease>

AppStreamIntegration * AppStreamIntegration::global()
{
    static AppStreamIntegration * var = nullptr;
    if (!var) {
        var = new AppStreamIntegration;
    }

    return var;
}

QSharedPointer<OdrsReviewsBackend> AppStreamIntegration::reviews()
{
    QSharedPointer<OdrsReviewsBackend> ret;
    if (m_reviews) {
        ret = m_reviews;
    } else {
        ret = QSharedPointer<OdrsReviewsBackend>(new OdrsReviewsBackend());
        m_reviews = ret;
    }
    return ret;
}
